==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/floppy/dialogs_pl.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Wygląda na to, że w końcu dotarliśmy.")


dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("Myślisz, że to tu?")


dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("Jak to się wszystko zmieściło na jednej trzyipółcalowej dyskietce?")


dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Zobacz jaka ona wielka. To raczej trzyipółmetrowa dyskietka.")


dialogId("disk-m-velka", "font_small", "That`s better. Big plan, big disk. That makes sense.")
dialogStr("To nawet lepiej. Wielki plan, wielki dysk. To ma sens.")


dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("Jak myślisz, podnesiemy ją jakoś?")


dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Ciężko będzie.")


dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("Nie wydaje mi się. Po co by ją tu chowali, jeśli moglibyśmy ją podnieść?")


dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("Zamilcz, bo ci nóżki powyłamuję!")


dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("Widzisz ten stalowy krzyż? Tu pogrzebane są nasze nadzieje.")


dialogId("disk-m-depres", "font_small", "Don`t be always so gloomy. I can`t bear it.")
dialogStr("Nie smęć tak ciągle. Nie chce mi się już słuchać.")


dialogId("disk-m-nahrat", "font_small", "Wouldn`t it be enough to download that plan from the floppy to our notebook?")
dialogStr("Nie wystarczyłoby zgrać plan z dyskietki na naszego laptopa?")


dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Czemu nie. Daj go tu.?")


dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("O cholera! Zostawiłam w domu.")


dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("Wracamy się po niego?")


dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Nigdy! Możesz się śmiać, ale mam już odciski na płetwach.")


dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Jak tam uważasz. Ciekaw jestem, jak to teraz zrobisz.")


dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("A co jeśli na tej dyskietce nie ma planu? Może ona jest tu tylko dla zmyłki?")


dialogId("disk-v-neverim", "font_big", "I don`t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("Nie wierzę. Widzisz tu jakiś inny przedmiot, który byłoby tak trudno wydostać?")


dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("Co to za stworki?")


dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("Pewnie wirusy komputerowe.")


dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Fuj. To dopiero potwory.")


dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn`t be happy if we pour them on their desktop.")
dialogStr("Musimy uważać, aby nie wynieść ich razem z dyskietką. Gracz nie byłby zachwycony, gdybyśmy mu je rozsypali po pulpicie.")


dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Naszym zadaniem jest wydostanie stąd tej dyskietki.")


dialogId("disk-x-nepohnes", "font_darkgrey", "You won`t move me easily!")
dialogStr("Nie poruszysz mnie tak łatwo!")


dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("To było sprytne!")


dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Ojej!")


dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("Kurczę!")


dialogId("disk-x-au0", "font_darkgrey", "Oh.")
dialogStr("Au.")


dialogId("disk-x-au1", "font_darkgrey", "Ouch.")
dialogStr("Ałć.")


dialogId("disk-x-au2", "font_darkgrey", "Yup.")
dialogStr("Au.")


dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("Zostaw mnie wreszcie w spokoju!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/floppy/dialogs_pl.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Wygląda na to, że w końcu dotarliśmy.")


dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("Myślisz, że to tu?")


dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("Jak to się wszystko zmieściło na jednej trzyipółcalowej dyskietce?")


dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Zobacz jaka ona wielka. To raczej trzyipółmetrowa dyskietka.")


dialogId("disk-m-velka", "font_small", "That’s better. Big plan, big disk. That makes sense.")
dialogStr("To nawet lepiej. Wielki plan, wielki dysk. To ma sens.")


dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("Jak myślisz, podnesiemy ją jakoś?")


dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Ciężko będzie.")


dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("Nie wydaje mi się. Po co by ją tu chowali, jeśli moglibyśmy ją podnieść?")


dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("Zamilcz, bo ci nóżki powyłamuję!")


dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("Widzisz ten stalowy krzyż? Tu pogrzebane są nasze nadzieje.")


dialogId("disk-m-depres", "font_small", "Don’t be always so gloomy. I can’t bear it.")
dialogStr("Nie smęć tak ciągle. Nie chce mi się już słuchać.")


dialogId("disk-m-nahrat", "font_small", "Wouldn’t it be enough to download that plan from the floppy to our notebook?")
dialogStr("Nie wystarczyłoby zgrać plan z dyskietki na naszego laptopa?")


dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Czemu nie. Daj go tu.?")


dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("O cholera! Zostawiłam w domu.")


dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("Wracamy się po niego?")


dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Nigdy! Możesz się śmiać, ale mam już odciski na płetwach.")


dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Jak tam uważasz. Ciekaw jestem, jak to teraz zrobisz.")


dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("A co jeśli na tej dyskietce nie ma planu? Może ona jest tu tylko dla zmyłki?")


dialogId("disk-v-neverim", "font_big", "I don’t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("Nie wierzę. Widzisz tu jakiś inny przedmiot, który byłoby tak trudno wydostać?")


dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("Co to za stworki?")


dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("Pewnie wirusy komputerowe.")


dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Fuj. To dopiero potwory.")


dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn’t be happy if we pour them on their desktop.")
dialogStr("Musimy uważać, aby nie wynieść ich razem z dyskietką. Gracz nie byłby zachwycony, gdybyśmy mu je rozsypali po pulpicie.")


dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Naszym zadaniem jest wydostanie stąd tej dyskietki.")


dialogId("disk-x-nepohnes", "font_darkgrey", "You won’t move me easily!")
dialogStr("Nie poruszysz mnie tak łatwo!")


dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("To było sprytne!")


dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Ojej!")


dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("Kurczę!")


dialogId("disk-x-au0", "font_darkgrey", "Oh.")
dialogStr("Au.")


dialogId("disk-x-au1", "font_darkgrey", "Ouch.")
dialogStr("Ałć.")


dialogId("disk-x-au2", "font_darkgrey", "Yup.")
dialogStr("Au.")


dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("Zostaw mnie wreszcie w spokoju!")
